==> openshift-model-miscellaneous-6.9.0-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/L4RedirectRuleFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class L4RedirectRuleFluent<A extends L4RedirectRuleFluent<A>> extends BaseFluent<A>{
  public L4RedirectRuleFluent() {
  }
  
  public L4RedirectRuleFluent(L4RedirectRule instance) {
    this.copyInstance(instance);
  }
  private String destinationIP;
  private Integer port;
  private String protocol;
  private Integer targetPort;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(L4RedirectRule instance) {
    instance = (instance != null ? instance : new L4RedirectRule());
  
    if (instance != null) {
        this.withDestinationIP(instance.getDestinationIP());
        this.withPort(instance.getPort());
        this.withProtocol(instance.getProtocol());
        this.withTargetPort(instance.getTargetPort());
        this.withDestinationIP(instance.getDestinationIP());
        this.withPort(instance.getPort());
        this.withProtocol(instance.getProtocol());
        this.withTargetPort(instance.getTargetPort());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getDestinationIP() {
    return this.destinationIP;
  }
  
  public A withDestinationIP(String destinationIP) {
    this.destinationIP=destinationIP; return (A) this;
  }
  
  public boolean hasDestinationIP() {
    return this.destinationIP != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public String getProtocol() {
    return this.protocol;
  }
  
  public A withProtocol(String protocol) {
    this.protocol=protocol; return (A) this;
  }
  
  public boolean hasProtocol() {
    return this.protocol != null;
  }
  
  public Integer getTargetPort() {
    return this.targetPort;
  }
  
  public A withTargetPort(Integer targetPort) {
    this.targetPort=targetPort; return (A) this;
  }
  
  public boolean hasTargetPort() {
    return this.targetPort != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    L4RedirectRuleFluent that = (L4RedirectRuleFluent) o;
    if (!java.util.Objects.equals(destinationIP, that.destinationIP)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    if (!java.util.Objects.equals(protocol, that.protocol)) return false;
  
    if (!java.util.Objects.equals(targetPort, that.targetPort)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destinationIP,  port,  protocol,  targetPort,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destinationIP != null) { sb.append("destinationIP:"); sb.append(destinationIP + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (targetPort != null) { sb.append("targetPort:"); sb.append(targetPort + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> openshift-model-miscellaneous-6.9.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/L4RedirectRuleFluent.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class L4RedirectRuleFluent<A extends L4RedirectRuleFluent<A>> extends BaseFluent<A>{
  public L4RedirectRuleFluent() {
  }
  
  public L4RedirectRuleFluent(L4RedirectRule instance) {
    this.copyInstance(instance);
  }
  private String destinationIP;
  private Integer port;
  private String protocol;
  private Integer targetPort;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(L4RedirectRule instance) {
    instance = (instance != null ? instance : new L4RedirectRule());
    if (instance != null) {
          this.withDestinationIP(instance.getDestinationIP());
          this.withPort(instance.getPort());
          this.withProtocol(instance.getProtocol());
          this.withTargetPort(instance.getTargetPort());
          this.withDestinationIP(instance.getDestinationIP());
          this.withPort(instance.getPort());
          this.withProtocol(instance.getProtocol());
          this.withTargetPort(instance.getTargetPort());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getDestinationIP() {
    return this.destinationIP;
  }
  
  public A withDestinationIP(String destinationIP) {
    this.destinationIP = destinationIP;
    return (A) this;
  }
  
  public boolean hasDestinationIP() {
    return this.destinationIP != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port = port;
    return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public String getProtocol() {
    return this.protocol;
  }
  
  public A withProtocol(String protocol) {
    this.protocol = protocol;
    return (A) this;
  }
  
  public boolean hasProtocol() {
    return this.protocol != null;
  }
  
  public Integer getTargetPort() {
    return this.targetPort;
  }
  
  public A withTargetPort(Integer targetPort) {
    this.targetPort = targetPort;
    return (A) this;
  }
  
  public boolean hasTargetPort() {
    return this.targetPort != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    L4RedirectRuleFluent that = (L4RedirectRuleFluent) o;
    if (!java.util.Objects.equals(destinationIP, that.destinationIP)) return false;
    if (!java.util.Objects.equals(port, that.port)) return false;
    if (!java.util.Objects.equals(protocol, that.protocol)) return false;
    if (!java.util.Objects.equals(targetPort, that.targetPort)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(destinationIP,  port,  protocol,  targetPort,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (destinationIP != null) { sb.append("destinationIP:"); sb.append(destinationIP + ","); }
    if (port != null) { sb.append("port:"); sb.append(port + ","); }
    if (protocol != null) { sb.append("protocol:"); sb.append(protocol + ","); }
    if (targetPort != null) { sb.append("targetPort:"); sb.append(targetPort + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
